docs.rs failed to build ckb-tx-pool-1.3.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build:
ckb-tx-pool-1.2.2
ckb-tx-pool
This crate is a component of ckb.
CKB Tx-pool stores transactions, which is designed for CKB Two Step Transaction Confirmation mechanism