CandidateUncles

Struct CandidateUncles 

pub struct CandidateUncles { /* private fields */ }
Candidate uncles container

Implementations

Source

impl CandidateUncles

pub fn new() -> CandidateUncles

Construct new candidate uncles container

pub fn insert(&mut self, uncle: UncleBlockView) -> bool

insert new candidate uncles If the map did not have this value present, true is returned. If the map did have this value present, false is returned.

pub fn len(&self) -> usize

Returns the number of elements in the container.

pub fn is_empty(&self) -> bool

Returns true if the container contains no elements.

pub fn contains(&self, uncle: &UncleBlockView) -> bool

Returns true if the container contains a value.

pub fn values(&self) -> impl Iterator<Item = &UncleBlockView>

Gets an iterator over the values of the map, in order by block_number.

pub fn remove_by_number(&mut self, uncle: &UncleBlockView) -> bool

Removes uncles from the container by specified uncle’s number

pub fn prepare_uncles( &mut self, snapshot: &Snapshot, current_epoch_ext: &EpochExt, ) -> Vec<UncleBlockView>

Get uncles from snapshot and current states.