Enum ckb_tx_pool::error::Reject
source · pub enum Reject {
LowFeeRate(FeeRate, u64, u64),
ExceededMaximumAncestorsCount,
Full(String, u64),
Duplicated(Byte32),
Malformed(String),
DeclaredWrongCycles(u64, u64),
Resolve(OutPointError),
Verification(Error),
Expiry(u64),
}Expand description
TX reject message
Variants
LowFeeRate(FeeRate, u64, u64)
Transaction fee lower than config
ExceededMaximumAncestorsCount
Transaction exceeded maximum ancestors count limit
Full(String, u64)
Transaction pool exceeded maximum size or cycles limit,
Duplicated(Byte32)
Transaction already exist in transaction_pool
Malformed(String)
Malformed transaction
DeclaredWrongCycles(u64, u64)
Declared wrong cycles
Resolve(OutPointError)
Resolve failed
Verification(Error)
Verification failed
Expiry(u64)
Expired
Implementations
sourceimpl Reject
impl Reject
sourcepub fn is_malformed_tx(&self) -> bool
pub fn is_malformed_tx(&self) -> bool
Returns true if the reject reason is malformed tx.
sourcepub fn is_allowed_relay(&self) -> bool
pub fn is_allowed_relay(&self) -> bool
Returns true if tx can be resubmitted, allowing relay
- Declared wrong cycles should allow relay with the correct cycles
- Reject but is not malformed and the fee rate reached the threshold, it may be due to double spending or temporary limitations of the pool resources, and expired clearing