Struct ckb_tx_pool::pool::TxPool
source · pub struct TxPool {
pub recent_reject: Option<RecentReject>,
/* private fields */
}Expand description
Tx-pool implementation
Fields
recent_reject: Option<RecentReject>record recent reject
Implementations
sourceimpl TxPool
impl TxPool
sourcepub fn status_size(&self, status: Status) -> usize
pub fn status_size(&self, status: Status) -> usize
Get tx-pool size
sourcepub fn update_statics_for_add_tx(&mut self, tx_size: usize, cycles: Cycle)
pub fn update_statics_for_add_tx(&mut self, tx_size: usize, cycles: Cycle)
Update size and cycles statics for add tx
sourcepub fn enable_rbf(&self) -> bool
pub fn enable_rbf(&self) -> bool
Check whether tx-pool enable RBF
sourcepub fn min_replace_fee(&self, tx: &TxEntry) -> Option<Capacity>
pub fn min_replace_fee(&self, tx: &TxEntry) -> Option<Capacity>
The least required fee rate to allow tx to be replaced
sourcepub fn update_statics_for_remove_tx(&mut self, tx_size: usize, cycles: Cycle)
pub fn update_statics_for_remove_tx(&mut self, tx_size: usize, cycles: Cycle)
Update size and cycles statics for remove tx cycles overflow is possible, currently obtaining cycles is not accurate