pub struct CandidateUncles { /* private fields */ }Expand description
Candidate uncles container
Implementations
Sourceimpl CandidateUncles
impl CandidateUncles
Sourcepub fn new() -> CandidateUncles
pub fn new() -> CandidateUncles
Construct new candidate uncles container
Sourcepub fn insert(&mut self, uncle: UncleBlockView) -> bool
pub fn insert(&mut self, uncle: UncleBlockView) -> bool
insert new candidate uncles If the map did not have this value present, true is returned. If the map did have this value present, false is returned.
Sourcepub fn contains(&self, uncle: &UncleBlockView) -> bool
pub fn contains(&self, uncle: &UncleBlockView) -> bool
Returns true if the container contains a value.
Sourcepub fn values(&self) -> impl Iterator<Item = &UncleBlockView>
pub fn values(&self) -> impl Iterator<Item = &UncleBlockView>
Gets an iterator over the values of the map, in order by block_number.
Sourcepub fn remove_by_number(&mut self, uncle: &UncleBlockView) -> bool
pub fn remove_by_number(&mut self, uncle: &UncleBlockView) -> bool
Removes uncles from the container by specified uncle’s number
Sourcepub fn prepare_uncles(
&mut self,
snapshot: &Snapshot,
current_epoch_ext: &EpochExt,
) -> Vec<UncleBlockView>
pub fn prepare_uncles( &mut self, snapshot: &Snapshot, current_epoch_ext: &EpochExt, ) -> Vec<UncleBlockView>
Get uncles from snapshot and current states.