Struct ckb_tx_pool::pool::TxPool

source ·
pub struct TxPool {
    pub recent_reject: Option<RecentReject>,
    /* private fields */
}
Tx-pool implementation

Fields

recent_reject: Option<RecentReject>

record recent reject

Implementations

source

impl TxPool

source

pub fn new(config: TxPoolConfig, snapshot: Arc<Snapshot>) -> TxPool

Create new TxPool

source

pub fn snapshot(&self) -> &Snapshot

Tx-pool owned snapshot, it may not consistent with chain cause tx-pool update snapshot asynchronously

source

pub fn cloned_snapshot(&self) -> Arc<Snapshot>

Makes a clone of the Arc

source

pub fn reach_size_limit(&self, tx_size: usize) -> bool

Whether Tx-pool reach size limit

source

pub fn reach_cycles_limit(&self, cycles: Cycle) -> bool

Whether Tx-pool reach cycles limit

source

pub fn update_statics_for_add_tx(&mut self, tx_size: usize, cycles: Cycle)

Update size and cycles statics for add tx

source

pub fn update_statics_for_remove_tx(&mut self, tx_size: usize, cycles: Cycle)

Update size and cycles statics for remove tx cycles overflow is possible, currently obtaining cycles is not accurate

source

pub fn add_pending(&mut self, entry: TxEntry) -> bool

Add tx to pending pool If did have this value present, false is returned.

source

pub fn add_gap(&mut self, entry: TxEntry) -> bool

Add tx which proposed but still uncommittable to gap pool

source

pub fn add_proposed(&mut self, entry: TxEntry) -> Result<bool, Reject>

Add tx to proposed pool

source

pub fn contains_proposal_id(&self, id: &ProposalShortId) -> bool

Returns true if the tx-pool contains a tx with specified id.

source

pub fn get_tx_with_cycles( &self, id: &ProposalShortId ) -> Option<(TransactionView, Cycle)>

Returns tx with cycles corresponding to the id.

source

pub fn get_tx(&self, id: &ProposalShortId) -> Option<&TransactionView>

Returns tx corresponding to the id.

source

pub fn get_entry_from_pending_or_gap( &self, id: &ProposalShortId ) -> Option<&TxEntry>

Returns tx from pending and gap corresponding to the id. RPC

source

pub fn get_proposals( &self, limit: usize, exclusion: &HashSet<ProposalShortId> ) -> HashSet<ProposalShortId>

Get to-be-proposal transactions that may be included in the next block.

source

pub fn get_tx_from_pool_or_store( &self, proposal_id: &ProposalShortId ) -> Option<TransactionView>

Returns tx from tx-pool or storage corresponding to the id.