pub struct TxPool {
    pub recent_reject: Option<RecentReject>,
    /* private fields */
}
Tx-pool implementation

Fields

recent_reject: Option<RecentReject>

record recent reject

Implementations

Create new TxPool

Tx-pool owned snapshot, it may not consistent with chain cause tx-pool update snapshot asynchronously

Makes a clone of the Arc

Whether Tx-pool reach size limit

Whether Tx-pool reach cycles limit

Update size and cycles statics for add tx

Update size and cycles statics for remove tx cycles overflow is possible, currently obtaining cycles is not accurate

Add tx to pending pool If did have this value present, false is returned.

Add tx which proposed but still uncommittable to gap pool

Add tx to proposed pool

Get last txs in tx-pool update timestamp

Returns true if the tx-pool contains a tx with specified id.

Returns tx with cycles corresponding to the id.

Returns tx corresponding to the id.

Returns tx from pending and gap corresponding to the id. RPC

Get to-be-proposal transactions that may be included in the next block.

Returns tx from tx-pool or storage corresponding to the id.