Struct ckb_tx_pool::pool::TxPool [−][src]
pub struct TxPool { /* fields omitted */ }Expand description
Tx-pool implementation
Implementations
Create new TxPool
Tx-pool owned snapshot, it may not consistent with chain cause tx-pool update snapshot asynchronously
Makes a clone of the Arc
Tx-pool information
Whether Tx-pool reach size limit
Whether Tx-pool reach cycles limit
Update size and cycles statics for add tx
Update size and cycles statics for remove tx cycles overflow is possible, currently obtaining cycles is not accurate
Add tx to pending pool If did have this value present, false is returned.
Add tx which proposed but still uncommittable to gap pool
Get last txs in tx-pool update timestamp
Returns true if the tx-pool contains a tx with specified id.
Returns tx with cycles corresponding to the id.
Returns tx corresponding to the id.
Returns tx exclude conflict corresponding to the id. RPC
pub fn get_proposals(
&self,
limit: usize,
exclusion: &HashSet<ProposalShortId>
) -> HashSet<ProposalShortId>
pub fn get_proposals(
&self,
limit: usize,
exclusion: &HashSet<ProposalShortId>
) -> HashSet<ProposalShortId>
Get to-be-proposal transactions that may be included in the next block.
pub fn get_tx_from_pool_or_store(
&self,
proposal_id: &ProposalShortId
) -> Option<TransactionView>
pub fn get_tx_from_pool_or_store(
&self,
proposal_id: &ProposalShortId
) -> Option<TransactionView>
Returns tx from tx-pool or storage corresponding to the id.