Struct ckb_tx_pool::pool::TxPoolInfo
source · [−]pub struct TxPoolInfo {
pub tip_hash: Byte32,
pub tip_number: BlockNumber,
pub pending_size: usize,
pub proposed_size: usize,
pub orphan_size: usize,
pub total_tx_size: usize,
pub total_tx_cycles: Cycle,
pub last_txs_updated_at: u64,
}Expand description
Transaction pool information.
Fields
tip_hash: Byte32The associated chain tip block hash.
Transaction pool is stateful. It manages the transactions which are valid to be commit after this block.
tip_number: BlockNumberThe block number of the block tip_hash.
pending_size: usizeCount of transactions in the pending state.
The pending transactions must be proposed in a new block first.
proposed_size: usizeCount of transactions in the proposed state.
The proposed transactions are ready to be commit in the new block after the block
tip_hash.
orphan_size: usizeCount of orphan transactions.
An orphan transaction has an input cell from the transaction which is neither in the chain nor in the transaction pool.
total_tx_size: usizeTotal count of transactions in the pool of all the different kinds of states.
total_tx_cycles: CycleTotal consumed VM cycles of all the transactions in the pool.
last_txs_updated_at: u64Last updated time. This is the Unix timestamp in milliseconds.